Documentation
¶
Overview ¶
Package slackbot allows posting messages to Slack using the Slackbot API
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type SlackBot ¶
type SlackBot struct {
// contains filtered or unexported fields
}
SlackBot stores the the current config and methods
func (SlackBot) PostMessage ¶
PostMessage sends the given message to the given channel as Slackbot
Click to show internal directories.
Click to hide internal directories.